@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Create network transition chord progressions
 
-our $VERSION = '0.0001';
+our $VERSION = '0.0002';
 
 use Data::Dumper::Compact qw(ddc);
 use Graph::Directed;
@@ -38,7 +38,7 @@ has net => (
 );
 
 
-has valence => (
+has chords => (
     is      => 'ro',
     isa     => sub { die "$_[0] is not a arrayref" unless ref $_[0] eq 'ARRAY' },
     default => sub { ['', 'm', 'm', '', '', 'm'] },
@@ -103,7 +103,7 @@ sub generate {
             $self->graph->add_edge($posn, $p);
         }
     }
-    print 'Graph: ' . $self->graph if $self->verbose;
+    print 'Graph: ' . $self->graph, "\n" if $self->verbose;
 
     # Create a random progression
     my @progression;
@@ -121,7 +121,7 @@ sub generate {
 
     my @scale = get_scale_notes($self->scale_note, $self->scale_name);
 
-    my @phrase = map { $scale[$_ - 1] . $self->valence->[$_ - 1] } @progression;
+    my @phrase = map { $scale[$_ - 1] . $self->chords->[$_ - 1] } @progression;
     print "Phrase: @phrase\n" if $self->verbose;
 
     # Add octaves to the chord notes
@@ -166,7 +166,7 @@ Music::Chord::Progression - Create network transition chord progressions
 
 =head1 VERSION
 
-version 0.0001
+version 0.0002
 
 =head1 SYNOPSIS
 
@@ -202,7 +202,7 @@ Default:
     5 => [qw( 1 )],
     6 => [qw( 2 4 )] }
 
-=head2 valence
+=head2 chords
 
 The chord name parts of each scale position.
 
@@ -258,7 +258,7 @@ Show the progress of the B<generate> method.
   $prog = Music::Chord::Progression->new;
   $prog = Music::Chord::Progression->new(
     net        => { 1 => [...], ... },
-    valence    => ['m','','m','m','',''],
+    chords     => ['m','','m','m','',''],
     scale_name => 'minor',
     scale_note => 'A',
     octave     => 5,
